---
title: How to say TreadI
parent: Reference
---

To say TreadI, say ["tread"](https://www.merriam-webster.com/dictionary/tread) followed by ["eye"](https://www.merriam-webster.com/dictionary/tread).

TreadI rhymes with [Jedi](https://en.wikipedia.org/wiki/Jedi).